Fix import sorting in soc.views.models.program module and rename any "Org" in link names to "Organization".
authorPawel Solyga <Pawel.Solyga@gmail.com>
Sun, 15 Feb 2009 18:55:05 +0000
changeset 1352 4f118840617f
parent 1351 8f66731fe62d
child 1353 14a024c71415
Fix import sorting in soc.views.models.program module and rename any "Org" in link names to "Organization". Patch by: Pawel Solyga Review by: to-be-reviewed
app/soc/views/models/program.py
--- a/app/soc/views/models/program.py	Sun Feb 15 18:53:56 2009 +0000
+++ b/app/soc/views/models/program.py	Sun Feb 15 18:55:05 2009 +0000
@@ -28,9 +28,9 @@
 
 from soc.logic import dicts
 from soc.logic.helper import timeline as timeline_helper
-from soc.logic.models.document import logic as document_logic
 from soc.logic.models import host as host_logic
 from soc.logic.models import program as program_logic
+from soc.logic.models.document import logic as document_logic
 from soc.views import helper
 from soc.views import out_of_band
 from soc.views.helper import access
@@ -207,7 +207,7 @@
 
         items += [(redirects.getReviewOverviewRedirect(
             entity, {'url_name': 'org_app'}),
-            "Review Org Applications", 'any_access')]
+            "Review Organization Applications", 'any_access')]
         # add link to edit Program Profile
         items += [(redirects.getEditRedirect(entity, params),
             'Edit Program Profile','any_access')]
@@ -249,11 +249,11 @@
           "Apply to become an Organization", 'any_access')]
 
       if user:
         # add the 'List my Org Applications' link
         items += [
             (redirects.getListSelfRedirect(program_entity, 
                                            {'url_name' : 'org_app'}),
-             "List my Org Applications", 'any_access')]
+             "List My Organization Applications", 'any_access')]
 
     return items
@@ -249,11 +249,11 @@
 
       if user:
-        # add the 'List my Org Applications' link
+        # add the 'List my Organization Applications' link
         items += [
             (redirects.getListSelfRedirect(program_entity, 